@@ -284,7 +284,7 @@ class _shareCache(_shareData):
                 return False
         if not os.path.exists(self.fileName):
             try:
-                open(self.fileName, "w")
+                open(self.fileName, "w").close()
             except IOError:
                 self.printERROR(_("Failed to create file %s") % self.fileName)
                 return False
